<?php 

namespace Teknisa\CNC\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DB\StorageProcedure\Param;

use Teknisa\Libs\Util\Environment;
use Teknisa\CNC\Services\Cnc01700ParametrizacaoProdutoService;

class Cnc01700ParametrizacaoProduto extends \Teknisa\CNC\Controllers\TeknisaCrud {
    
    const ADQUIRENTES = 'cnc01700_parametrizacao_produto';
    const ADQCLIENTES = 'cnc01700_parametrizacao_produto_cliente';
    const AJUSTENEGATIVO = 'cnc01700_parametrizacao_produto_ajuste_neg';
    const AJUSTEPOSITIVO = 'cnc01700_parametrizacao_produto_findAdqAjtPos';
    const PRODUTOS = 'cnc01700_parametrizacao_produto_getProduto';
    const TPOPER = 'cnc01700_parametrizacao_produto_tpoper';
    const CONTREC = 'cnc01700_parametrizacao_produto_contaRecebe';
    const TPAJUSTE = 'cnc01700_parametrizacao_produto_tpAjuste';
    const TPDEBITO = 'cnc01700_parametrizacao_produto_tpDebito';
    const TPCREDITO = 'cnc01700_parametrizacao_produto_tpcredito';
    protected $dataSourceName;
	protected $parameterBagColumns;
	
    public function __construct($crudService, ParameterBag $parameterBagColumns, Cnc01700ParametrizacaoProdutoService $service, Environment $environment){
	    parent::__construct($crudService, $parameterBagColumns);
        $this->service = $service;
        $this->environment = $environment;
    }
    
    public function findAdq(DTO\Request\Filter $request, DTO\Response $response){
        $this->dataSourceName = self::ADQUIRENTES;
        parent::find($request,$response);        
    }
    
    public function getProdutosGer(DTO\Request\Filter $request, DTO\Response $response){
        $this->dataSourceName = self::PRODUTOS;
        parent::find($request,$response);        
    }

    
    public function findAdqClientes(DTO\Request\Filter $request, DTO\Response $response){
        $this->dataSourceName = self::ADQCLIENTES;
        parent::find($request,$response);        
    }
        
    public function findAdqAjtNeg(DTO\Request\Filter $request, DTO\Response $response){
        $this->dataSourceName = self::AJUSTENEGATIVO;
        parent::find($request,$response);        
    }
    
    public function findAdqAjtPos(DTO\Request\Filter $request, DTO\Response $response){
        $this->dataSourceName = self::AJUSTEPOSITIVO;
        parent::find($request,$response);        
    }
    
    public function saveCliente(DTO\Request $request, DTO\Response $response) {
		try {
            $row = $request->getDataSet()->getRows()[0];
            $row["NRORG"] = $this->environment->getNrOrgTrab();
            $result = $this->service->saveCliente($row);
    		$response->addNotification(new Notification("Dados salvos com sucesso!"), Notification::TYPE_SUCCESS);
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
    
    public function produtoTab (DTO\Request $request, DTO\Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $result = $this->service->produtoTab($params);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('cnc01700_parametrizacao_produto_produtotab', $result));
        } catch (\Exception $e) {
           $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function saveNewProdutoParams(DTO\Request $request, DTO\Response $response) {
		try {
            $row = $request->getDataSet()->getRows()[0];
            $row["NRORG"] = $this->environment->getNrOrgTrab();
            $result = $this->service->saveNewProdutoParams($row);
            if($result != 1){
    		    $response->addNotification(new Notification("Dados salvos com sucesso!"), Notification::TYPE_SUCCESS);
            }
            else{
                throw new \Exception('Produto já parametrizado para a Adquirente e o Estabelecimento selecionado.', 1);
            }
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), $e->getCode()));
		}
	}
	
    public function saveNewEstabelecParams(DTO\Request $request, DTO\Response $response) {
		try {
            $row = $request->getDataSet()->getRows()[0];
            $row["NRORG"] = $this->environment->getNrOrgTrab();
            $result = $this->service->saveNewEstabelecParams($row);
            if($result != 1){
    		    $response->addNotification(new Notification("Dados salvos com sucesso!"), Notification::TYPE_SUCCESS);
            }
            else{
                throw new \Exception('Produto já parametrizado para a Adquirente e o Estabelecimento selecionado.', 1);
            }
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), $e->getCode()));
		}
	}
	
	public function saveProdutoParamsEdit(DTO\Request $request, DTO\Response $response) {
		try {
            $row = $request->getDataSet()->getRows()[0];
            $row["NRORG"] = $this->environment->getNrOrgTrab();
            $result = $this->service->saveProdutoParamsEdit($row);
    		$response->addNotification(new Notification("Dados salvos com sucesso!"), Notification::TYPE_SUCCESS);
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), $e->getCode()));
		}
	}
	
	public function saveProdutoParamsEditProd(DTO\Request $request, DTO\Response $response) {
		try {
            $row = $request->getDataSet()->getRows()[0];
            $row["NRORG"] = $this->environment->getNrOrgTrab();
            $result = $this->service->saveProdutoParamsEditProd($row);
            if($result != 1){
    		    $response->addNotification(new Notification("Dados salvos com sucesso!"), Notification::TYPE_SUCCESS);
            }else{
                throw new \Exception('Produto já parametrizado para a Adquirente e o Estabelecimento selecionado.', 1);
            }
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), $e->getCode()));
		}
	}

    public function editEstabelec(DTO\Request $request, DTO\Response $response) {
		try {
            $row = $request->getDataSet()->getRows()[0];
            $row["NRORG"] = $this->environment->getNrOrgTrab();
            $result = $this->service->editEstabelec($row);
            if($result != 1){
    		    $response->addNotification(new Notification("Dados salvos com sucesso!"), Notification::TYPE_SUCCESS);
            }
            else{
                throw new \Exception('Estabelecimento já parametrizado para o Produto e a Adquirente selecionada.', 1);
            }
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), $e->getCode()));
		}
	}

    public function editNewEstabelec(DTO\Request $request, DTO\Response $response) {
		try {
            $row = $request->getDataSet()->getRows()[0];
            $row["NRORG"] = $this->environment->getNrOrgTrab();
            $result = $this->service->editNewEstabelec($row);
            if($result != 1){
    		    $response->addNotification(new Notification("Dados salvos com sucesso!"), Notification::TYPE_SUCCESS);
            }
            else{
                throw new \Exception('Estabelecimento já parametrizado para o Produto e a Adquirente selecionada.', 1);
            }
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), $e->getCode()));
		}
	}

	public function getTpCredito(DTO\Request $request, DTO\Response $response){
        $this->dataSourceName = self::TPCREDITO;
        parent::find($request,$response);        
    }

	public function getTpOper(DTO\Request $request, DTO\Response $response){
        $this->dataSourceName = self::TPOPER;
        parent::find($request,$response);        
    }
    
    public function getContaRec(DTO\Request $request, DTO\Response $response){
        $this->dataSourceName = self::CONTREC;
        parent::find($request,$response);        
    }
    
    public function getTpAjuste(DTO\Request $request, DTO\Response $response){
        $this->dataSourceName = self::TPAJUSTE;
        parent::find($request,$response);        
    }
    
    public function getTpDebito(DTO\Request $request, DTO\Response $response){
        $this->dataSourceName = self::TPDEBITO;
        parent::find($request,$response);        
    }
    
    public function deleteProduto(DTO\Request $request, DTO\Response $response) {
	    try {
	        $row = $request->getDataSet()->getRows()[0];
            $row["NRORG"] = $this->environment->getNrOrgTrab();
            $this->service->deleteProduto($row);
            $response->addNotification(new Notification("Dados apagados com sucesso!"), Notification::TYPE_SUCCESS);
	        
	    } catch (\Exception $e) {
	        $response->setError(new Error($e->getMessage(), $e->getCode()));
	    }
	}
	
	public function deleteEstabelec(DTO\Request $request, DTO\Response $response) {
	    try {
	        $row = $request->getDataSet()->getRows()[0];
            $row["NRORG"] = $this->environment->getNrOrgTrab();
            $this->service->deleteEstabelec($row);
            $response->addNotification(new Notification("Dados apagados com sucesso!"), Notification::TYPE_SUCCESS);
	        
	    } catch (\Exception $e) {
	        $response->setError(new Error($e->getMessage(), $e->getCode()));
	    }
	}

    public function getProdutoEstabelec(DTO\Request $request, DTO\Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $resultadoFiltrado = $this->service->getProdutoEstabelec($params);

            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('cnc01700_parametrizacao_produto_estabelecimentos', $resultadoFiltrado));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    public function filterEstabelec(DTO\Request $request, DTO\Response $response){
        try{
            $params = $request->getFilterCriteria()->getConditions();
            $resultadoFiltrado = $this->service->filterEstabelec($params);
            
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('cnc01700_parametrizacao_produto_filterEstabelec', $resultadoFiltrado));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
}