<?php 

namespace Teknisa\CNC\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;

use Teknisa\CNC\Services\Cnc02800DataInicioIntegracaoService;
use Teknisa\Libs\Util\Environment;

use Teknisa\CNC\Utilities\UtilCNC;

class Cnc02800DataInicioIntegracao {
    protected $dataSourceName = 'cnc02800_data_inicio_integracao';
    protected $dataInclusaoService;
    protected $environment;
    protected $util;
    
    public function __construct(Cnc02800DataInicioIntegracaoService $dataInclusaoService, Environment $environment, UtilCNC $util) {
        $this->dataInclusaoService = $dataInclusaoService;
        $this->environment = $environment;
        $this->util = $util;
    }
    
    public function findDataOperador (DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $filter = $request->getFilterCriteria()->getConditions();
            $params["NRORG"] = $this->util->getParamValueFromFilter($filter, "NRORG");
            
            $dataSets = $this->dataInclusaoService->findDataOperador($params);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("cnc02800_data_inicio_integracao", $dataSets));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function saveDataOperador(DTO\Request $request, DTO\Response $response){
        try {
    	    $params = $request->getDataSet()->getRows();
            $isNew = $this->verifyExistData($params);
            $resultado = $this->dataInclusaoService->saveDataOperador($params, $isNew);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function findDataOperadorFilial (DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $dataSets = $this->dataInclusaoService->findDataOperadorFilial();
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("cnc02800_data_inicio_integracao_filial", $dataSets));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function saveDataOperadorFilial (DTO\Request $request, DTO\Response $response){
        try {
    	    $params = $request->getDataSet()->getRows();
            $isNew = $this->verifyExistDataFilial($params);
            $resultado = $this->dataInclusaoService->saveDataOperadorFilial($params, $isNew);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function verifyExistData($params){
        return $isNew = $this->dataInclusaoService->verifyExistData($params);
    }
    
    public function verifyExistDataFilial($params){
        return $isNew = $this->dataInclusaoService->verifyExistDataFilial($params);
    }
    
}