<?php
namespace Teknisa\CNC\Factories;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

use Doctrine\ORM\EntityManager;

class Cnc01100SimulacaoAntecipadaFactory {

    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }

    public function callAnticipatedSimulationProcedure($params) {
        $procedure = new StoredProcedure($this->connection, 'VALORLIQUIDOCNC');

        $procedure->addParam(new Param('P_NRESTABELEC', Param::PARAM_INPUT, $params["P_NRESTABELEC"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRADQ', Param::PARAM_INPUT, $params["P_NRADQ"], Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_PRODUTO', Param::PARAM_INPUT, $params["P_PRODUTO"], Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_VRBRUTO', Param::PARAM_INPUT, 0, Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_TAXA', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_INT, 50));
        $procedure->addParam(new Param('P_VRLIQ', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_INT, 50));

        $returnParameters = $procedure->execute();

        return $returnParameters;
    }

    public function getAnticipatedSimulation ($params) {
        $sql = "SELECT T.*, CO.CDCUPOM 
                  FROM (
                    SELECT TO_DATE(TO_CHAR(L.DTLOTE, 'DD/MM/YYYY'), 'DD/MM/YYYY') DTLOTE, '' DATAVENDA, TO_CHAR(R.NRLOTEVENDA) PRIMARY, '' PARENT, A.NMADQUIRENTE,
                                       '' NMESTABELEC, '' NMPRODUTOADQ, null CDNSU, SUM(R.VRBRUTVENDA) VRBRUTVENDA, SUM(R.VRLIQVENDA) VRLIQVENDA,  
                                       A.NRADQUIRENTE, null VRTAXAADM, L.CDLOTEVENDA, null NRCONCLANC, '' AS DATACREDITO, null NRESTABELEC, null NRPRODUTOADQ, R.NRLOTEVENDA
                                               FROM LOTEVENDA L, ADQUIRENTE A, RETVENDAADQ R,
                                               ESTABELECIMENTO E, PRODUTOADQ P
                                                WHERE R.NRLOTEVENDA = L.NRLOTEVENDA
                                                 AND R.NRADQUIRENTE           = A.NRADQUIRENTE
                                                 AND R.NRPRODUTOADQ       = P.NRPRODUTOADQ
                                                 AND R.NRESTABELEC       = E.NRESTABELEC
                                                 AND L.NRADQUIRENTE           = A.NRADQUIRENTE
                                                 AND L.NRADQUIRENTE        = R.NRADQUIRENTE
                                                 AND ((INSTR (:NRESTABELEC,     TO_CHAR(E.NRESTABELEC) ) <> 0) OR ('T' = :TNRESTABELEC))
                                                 AND ((INSTR (:NRADQUIRENTE,     TO_CHAR(A.NRADQUIRENTE) ) <> 0) OR ('T' = :TNRADQUIRENTE))
                                                 AND ((INSTR (:NRPRODUTOADQ, TO_CHAR(P.NRPRODUTOADQ) ) <> 0) OR ('T' = :TNRPRODUTOADQ))
                                                 AND (UPPER (L.CDLOTEVENDA) LIKE UPPER (:CDLOTEVENDA) OR (:TCDLOTEVENDA = 'T') )
                                                 AND ((UPPER (R.CDNSU) LIKE UPPER (:CDNSU)) OR ('T' = :TCDNSU))
                                                 AND L.IDTIPOLOTE <> 'A'
                                                 AND ((TRUNC(R.DTVENDA) BETWEEN TO_DATE(:DTVENDAINI, 'DD/MM/YY') AND TO_DATE(:DTVENDAFIN, 'DD/MM/YY')) )
                                                 AND ((TRUNC(R.DTCREDITO) BETWEEN TO_DATE(:DTCREDITOINI, 'DD/MM/YY') AND TO_DATE(:DTCREDITOFIN, 'DD/MM/YY')) )
                                                 AND ((:TALL_FIELDS = 'T') OR (INSTR(A.NMADQUIRENTE || '_' || 
                                                                                     E.NMESTABELEC || '_' || 
                                                                                     P.NMPRODUTOADQ || '_' || 
                                                                                     L.CDLOTEVENDA || '_' || 
                                                                                     CDNSU || '_' || 
                                                                                     L.DTLOTE || '_' || 
                                                                                     R.DTVENDA || '_' || 
                                                                                     R.DTCREDITO, :ALL_FIELDS) <> 0))
                                                 GROUP BY L.DTLOTE, L.CDLOTEVENDA, A.NMADQUIRENTE, A.NRADQUIRENTE, R.NRLOTEVENDA
                  UNION
                    SELECT NULL DTLOTE, TO_CHAR(R.DTVENDA, 'DD/MM/YYYY') AS DATAVENDA, '' PRIMARY, TO_CHAR(R.NRLOTEVENDA) PARENT,
                                          A.NMADQUIRENTE, E.NMESTABELEC, P.NMPRODUTOADQ, R.CDNSU, R.VRBRUTVENDA, R.VRLIQVENDA, A.NRADQUIRENTE, R.VRTAXAADM,
                                          L.CDLOTEVENDA, R.NRCONCLANC, TO_CHAR(R.DTCREDITO, 'DD/MM/YYYY') AS DATACREDITO, E.NRESTABELEC, P.NRPRODUTOADQ, R.NRLOTEVENDA
                                             FROM RETVENDAADQ R, PRODUTOADQ P, LOTEVENDA L, ADQUIRENTE A, ESTABELECIMENTO E
                                              WHERE R.NRLOTEVENDA = L.NRLOTEVENDA
                                               AND R.NRADQUIRENTE        = A.NRADQUIRENTE
                                               AND R.NRPRODUTOADQ    = P.NRPRODUTOADQ
                                               AND R.NRESTABELEC    = E.NRESTABELEC
                                               AND L.NRADQUIRENTE        = A.NRADQUIRENTE
                                               AND L.NRADQUIRENTE        = R.NRADQUIRENTE
                                               AND ((INSTR (:NRESTABELEC,  TO_CHAR(E.NRESTABELEC)  ) <> 0) OR ('T' = :TNRESTABELEC))
                                               AND ((INSTR (:NRADQUIRENTE, TO_CHAR(A.NRADQUIRENTE) ) <> 0) OR ('T' = :TNRADQUIRENTE))
                                               AND ((INSTR (:NRPRODUTOADQ, TO_CHAR(P.NRPRODUTOADQ) ) <> 0) OR ('T' = :TNRPRODUTOADQ))
                                               AND (UPPER (L.CDLOTEVENDA) LIKE UPPER (:CDLOTEVENDA) OR (:TCDLOTEVENDA = 'T'))
                                               AND ((UPPER (R.CDNSU) LIKE UPPER (:CDNSU)) OR ('T' = :TCDNSU))
                                               AND L.IDTIPOLOTE <> 'A'
                                               AND ((TRUNC(R.DTVENDA) BETWEEN TO_DATE(:DTVENDAINI, 'DD/MM/YY') AND TO_DATE(:DTVENDAFIN, 'DD/MM/YY')))
                                               AND ((TRUNC(R.DTCREDITO) BETWEEN TO_DATE(:DTCREDITOINI, 'DD/MM/YY') AND TO_DATE(:DTCREDITOFIN, 'DD/MM/YY')))
                                               AND ((:TALL_FIELDS = 'T') OR (INSTR(  A.NMADQUIRENTE || '_' || 
                                                                                     E.NMESTABELEC || '_' || 
                                                                                     P.NMPRODUTOADQ || '_' || 
                                                                                     L.CDLOTEVENDA || '_' || 
                                                                                     CDNSU || '_' || 
                                                                                     L.DTLOTE || '_' || 
                                                                                     R.DTVENDA || '_' || 
                                                                                     R.DTCREDITO, :ALL_FIELDS) <> 0))
                                               )T
                                    LEFT JOIN CONSMOVCAIXA CO
                                     ON T.NRCONCLANC = CO.NRCONCLANC
                                ORDER BY T.DTLOTE, CO.DTVENDA, NRESTABELEC, NMESTABELEC, DATACREDITO"; 
                                
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
}
