# Odhen Conciliador - WebService de Integração com o WebService das Conciliadoras.

Este serviço foi criado para realizar a importação de vendas e pagamentos conhecidos através do webservice SOAP das Conciliadoras (hoje disponível em: `https://webservice.conciliadora.com.br`). 
Após importar esses dados, este mesmo serviço, realiza a conciliação com os dados das aplicações Teknisa, povoando as bases de dados por meio de procedures.

# Instalação: 
O projeto utiliza o composer somente com o PSR-0, para garantir o registro dos namespaces. O código em si está escrito em PHP de forma nativa, funcionando na versão `PHP 7.2+`. É preciso instalar o composer para poder rodar o projeto.

### Passos para utilização:

1. Clonar o projeto.
2. Rodar o comando:
```
$ composer install
```
3. Parametrizar as variáveis/mnemônicos do WebService. 
4. Fazer uma requisição POST, passando o NRORG com o valor:
```
NRORG: "número da organização" // string ou integer
```

### Exemplo de chamada via cURL em um Terminal:

- curl -X POST URL/service/index.php -d NRORG=2588

# Produção

Em produção, de tempos em tempos o Jenkins executará o comando Shell acima para acionar o WebService.

# Documentação:
Este projeto pode utilizar o [composer][COMPOSER_LINK] para instalar a biblioteca [phpdoc][PHPDOC_LINK], reponsável por gerar a documentação do projeto. Por sua vez, essa biblioteca utiliza o GraphViz e o Git para gerar alguns gráficos do projeto.
- Para instalar o GraphViz e o Git:
```
$ sudo apt-get update
$ sudo apt-get install git graphviz
```
- Para gerar a documentação do projeto, basta rodar os seguintes comandos:

### Com Composer

```
$ cd /path/to/project
$ composer install
$ ./vendor/bin/phpdoc -d ./src -t ./docs/
```

### Sem Composer
```
$ curl  https://www.phpdoc.org/phpDocumentor.phar -o phpDocumentor.phar  
$ php phpDocumentor.phar -d ./src -t ./docs/
```

A pasta `docs` será gerada. Nela estará o arquivo `index.html`. É preciso acessá-lo por um navegador WEB para poder visualizar a documentação do projeto.

# Variáveis de Ambiente / Mnemônicos:
Este projeto possui as seguintes variáveis nos seguintes arquivos:

### [db.json][DBJSON_FILE]
*Obs: O Banco de dados é o Oracle SGBD*

- DB_ORA_HOST: Endereço do Host do Banco de Dados 
- DB_ORA_USER: Nome de usuário para logar no Banco de Dados.
- DB_ORA_PASSWORD: Senha do usuário para logar no Banco de Dados.
- DB_ORA_DBNAME: Identificador do Serviço de conexão com o banco de dados (TNSName)
- DB_ORA_CHARSET: Codificação de Caracteres do banco de dados, informado durante a conexão com o mesmo.
- DB_ORA_WALLET_BOOL: Booleano que identifica se utilizamos Wallet.
- DB_ORA_WALLET_PREFIX: Prefixo utilizado na conexão com os clientes SAAS. O default é "USR_ORG_".

### [config.json][CONFIGJSON_FILE]
- CNC_IS_PRODUCTION: Booleano que informa se irá utilizar as variáveis do arquivo de teste, ou buscá-las do Banco de Dados.
- CNC_DAYS_TO_BE_CONCILIATED: Inteiro com o número de dias serão contemplados na rotina.
- CNC_ID_EMPRESA_CONC: String que possui um conjunto de códigos de estabelecimentos que serão utilizados para definir quais estabelecimentos serão consultados no WebService.
- CNC_SENHA_CONC: String que possui um conjunto de senhas de estabelecimentos que serão utilizados para definir quais estabelecimentos serão consultados no WebService.
- PROXY_HOST: String com o endereço do Servidor de Proxy. (Não mais utilizado). 
- PROXY_PORT: String com a porta do Servidor de Proxy. (Não mais utilizado).
- PROXY_LOGIN: String com o username para logar no Servidor de Proxy. (Não mais utilizado).
- PROXY_PASSWORD: String com a senha para logar no Servidor de Proxy. (Não mais utilizado).
# Próximos passos:
- Separar este serviço em um repositório à parte. 
- Criação de testes unitários para o código.
- Expansão da documentação do projeto.
- Controle de acesso à este WebService via JWT (Sugestão, pois hoje não há nenhum controle).
- Adição de um roteamento para suportar outras rotinas semelhantes, como a integração com a Access Stage que ainda não foi contemplada.
- Otimização da rotina para melhorar a performance.
- Implementar a possibilidade de usar a senha criptografada do Delphi.

[COMPOSER_LINK]: <https://getcomposer.org/>
[PHPDOC_LINK]: <https://www.phpdoc.org/>
[DBJSON_FILE]: <http://code.zeedhi.com/odhen/cncbackend/tree/master/src/Teknisa/CNC/Utilities/CNCCallWebServices/config/db.json.template>
[CONFIGJSON_FILE]: <http://code.zeedhi.com/odhen/cncbackend/tree/master/src/Teknisa/CNC/Utilities/CNCCallWebServices/config/config.json.template>